/*
 $Id$
*/
#ifndef _VOSKO_H_
#define _VOSKO_H_

extern void   R_Vosko(double *, double *, double *, double *);
#endif
